@@ -16,3 +16,11 @@ tuple(  # comment
 tuple([  # comment
     1, 2
 ])
+
+tuple((
+    1,
+))
+
+t6 = tuple([1])
+t7 = tuple((1,))
+t8 = tuple([1,])
