@@ -84,6 +84,15 @@ pub(super) fn notification<'a>(notif: server::Notification) -> Task<'a> {
         }
         notification::DidClose::METHOD => local_notification_task::<notification::DidClose>(notif),
         notification::DidOpen::METHOD => local_notification_task::<notification::DidOpen>(notif),
+        notification::DidOpenNotebook::METHOD => {
+            local_notification_task::<notification::DidOpenNotebook>(notif)
+        }
+        notification::DidChangeNotebook::METHOD => {
+            local_notification_task::<notification::DidChangeNotebook>(notif)
+        }
+        notification::DidCloseNotebook::METHOD => {
+            local_notification_task::<notification::DidCloseNotebook>(notif)
+        }
         method => {
             tracing::warn!("Received notification {method} which does not have a handler.");
             return Task::nothing();
