@@ -1,10 +1,11 @@
 use std::borrow::Cow;
 
-use crate::edit::{DocumentVersion, WorkspaceEditTracker};
+use crate::edit::WorkspaceEditTracker;
+use crate::fix::Fixes;
 use crate::server::api::LSPResult;
 use crate::server::SupportedCodeAction;
 use crate::server::{client::Notifier, Result};
-use crate::session::{DocumentSnapshot, ResolvedClientCapabilities};
+use crate::session::{DocumentQuery, DocumentSnapshot, ResolvedClientCapabilities};
 use crate::PositionEncoding;
 use lsp_server::ErrorCode;
 use lsp_types::{self as types, request as req};
@@ -28,7 +29,7 @@ impl super::BackgroundDocumentRequestHandler for CodeActionResolve {
         _notifier: Notifier,
         mut action: types::CodeAction,
     ) -> Result<types::CodeAction> {
-        let document = snapshot.document();
+        let query = snapshot.query();
 
         let code_actions = SupportedCodeAction::from_kind(
             action
@@ -49,25 +50,22 @@ impl super::BackgroundDocumentRequestHandler for CodeActionResolve {
         };
 
         action.edit = match action_kind {
-            SupportedCodeAction::SourceFixAll => Some(
+            SupportedCodeAction::SourceFixAll | SupportedCodeAction::NotebookSourceFixAll => Some(
                 resolve_edit_for_fix_all(
-                    document,
+                    query,
                     snapshot.resolved_client_capabilities(),
-                    snapshot.url(),
-                    snapshot.settings().linter(),
+                    query.settings().linter(),
                     snapshot.encoding(),
-                    document.version(),
                 )
                 .with_failure_code(ErrorCode::InternalError)?,
             ),
-            SupportedCodeAction::SourceOrganizeImports => Some(
+            SupportedCodeAction::SourceOrganizeImports
+            | SupportedCodeAction::NotebookSourceOrganizeImports => Some(
                 resolve_edit_for_organize_imports(
-                    document,
+                    query,
                     snapshot.resolved_client_capabilities(),
-                    snapshot.url(),
-                    snapshot.settings().linter(),
+                    query.settings().linter(),
                     snapshot.encoding(),
-                    document.version(),
                 )
                 .with_failure_code(ErrorCode::InternalError)?,
             ),
@@ -84,54 +82,46 @@ impl super::BackgroundDocumentRequestHandler for CodeActionResolve {
 }
 
 pub(super) fn resolve_edit_for_fix_all(
-    document: &crate::edit::Document,
+    query: &DocumentQuery,
     client_capabilities: &ResolvedClientCapabilities,
-    url: &types::Url,
     linter_settings: &LinterSettings,
     encoding: PositionEncoding,
-    version: DocumentVersion,
 ) -> crate::Result<types::WorkspaceEdit> {
     let mut tracker = WorkspaceEditTracker::new(client_capabilities);
-    tracker.set_edits_for_document(
-        url.clone(),
-        version,
-        fix_all_edit(document, url, linter_settings, encoding)?,
+    tracker.set_fixes_for_document(
+        fix_all_edit(query, linter_settings, encoding)?,
+        query.version(),
     )?;
     Ok(tracker.into_workspace_edit())
 }
 
 pub(super) fn fix_all_edit(
-    document: &crate::edit::Document,
-    document_url: &types::Url,
+    query: &DocumentQuery,
     linter_settings: &LinterSettings,
     encoding: PositionEncoding,
-) -> crate::Result<Vec<types::TextEdit>> {
-    crate::fix::fix_all(document, document_url, linter_settings, encoding)
+) -> crate::Result<Fixes> {
+    crate::fix::fix_all(query, linter_settings, encoding)
 }
 
 pub(super) fn resolve_edit_for_organize_imports(
-    document: &crate::edit::Document,
+    query: &DocumentQuery,
     client_capabilities: &ResolvedClientCapabilities,
-    url: &types::Url,
     linter_settings: &ruff_linter::settings::LinterSettings,
     encoding: PositionEncoding,
-    version: DocumentVersion,
 ) -> crate::Result<types::WorkspaceEdit> {
     let mut tracker = WorkspaceEditTracker::new(client_capabilities);
-    tracker.set_edits_for_document(
-        url.clone(),
-        version,
-        organize_imports_edit(document, url, linter_settings, encoding)?,
+    tracker.set_fixes_for_document(
+        organize_imports_edit(query, linter_settings, encoding)?,
+        query.version(),
     )?;
     Ok(tracker.into_workspace_edit())
 }
 
 pub(super) fn organize_imports_edit(
-    document: &crate::edit::Document,
-    document_url: &types::Url,
+    query: &DocumentQuery,
     linter_settings: &LinterSettings,
     encoding: PositionEncoding,
-) -> crate::Result<Vec<types::TextEdit>> {
+) -> crate::Result<Fixes> {
     let mut linter_settings = linter_settings.clone();
     linter_settings.rules = [
         Rule::UnsortedImports,       // I001
@@ -140,5 +130,5 @@ pub(super) fn organize_imports_edit(
     .into_iter()
     .collect();
 
-    crate::fix::fix_all(document, document_url, &linter_settings, encoding)
+    crate::fix::fix_all(query, &linter_settings, encoding)
 }
