@@ -39,6 +39,7 @@ KNOWN_FORMATTING_VIOLATIONS = [
     "blank-lines-before-nested-definition",
     "blank-lines-top-level",
     "explicit-string-concatenation",
+    "f-string-missing-placeholders",
     "indent-with-spaces",
     "indentation-with-invalid-multiple",
     "line-too-long",
@@ -73,7 +74,6 @@ KNOWN_FORMATTING_VIOLATIONS = [
     "redundant-backslash",
     "shebang-leading-whitespace",
     "surrounding-whitespace",
-    "tab-indentation",
     "too-few-spaces-before-inline-comment",
     "too-many-blank-lines",
     "too-many-boolean-expressions",
